aboutgitcodelistschat:MatrixIRC
path: root/gluten.h
diff options
context:
space:
mode:
authorAlice Frosi <afrosi@redhat.com>2023-02-22 15:52:54 +0100
committerAlice Frosi <afrosi@redhat.com>2023-02-22 16:15:03 +0100
commit977ffec509a95efeca2b7c508912d5d1df7cd677 (patch)
tree3d5c169951b05008415d5eafdf263c51e8cf164d /gluten.h
parentba9623361f74be93674f2862903a39ae6d48e96e (diff)
downloadseitan-977ffec509a95efeca2b7c508912d5d1df7cd677.tar
seitan-977ffec509a95efeca2b7c508912d5d1df7cd677.tar.gz
seitan-977ffec509a95efeca2b7c508912d5d1df7cd677.tar.bz2
seitan-977ffec509a95efeca2b7c508912d5d1df7cd677.tar.lz
seitan-977ffec509a95efeca2b7c508912d5d1df7cd677.tar.xz
seitan-977ffec509a95efeca2b7c508912d5d1df7cd677.tar.zst
seitan-977ffec509a95efeca2b7c508912d5d1df7cd677.zip
Rename actions to operations
Replace all the action related names to operations to make them more generic.
Diffstat (limited to 'gluten.h')
-rw-r--r--gluten.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/gluten.h b/gluten.h
index e027923..1b6c3d1 100644
--- a/gluten.h
+++ b/gluten.h
@@ -36,20 +36,20 @@ enum ns_type {
};
/*
* struct act_context - Description of the context where the call needs to be executed
* @ns: Descrption of the each namespace where the call needs to be executed
*/
-struct act_context {
+struct op_context {
struct ns_spec ns[sizeof(enum ns_type)];
};
-enum action_type {
- A_CALL,
- A_BLOCK,
- A_CONT,
- A_INJECT,
- A_INJECT_A,
- A_RETURN,
+enum op_type {
+ OP_CALL,
+ OP_BLOCK,
+ OP_CONT,
+ OP_INJECT,
+ OP_INJECT_A,
+ OP_RETURN,
};
enum value_type {
@@ -57,23 +57,23 @@ enum value_type {
REFERENCE,
};
-struct act_call {
+struct op_call {
long nr;
bool has_ret;
void *args[6];
- struct act_context context;
+ struct op_context context;
uint16_t ret_off;
};
-struct act_block {
+struct op_block {
int32_t error;
};
-struct act_continue {
+struct op_continue {
bool cont;
};
-struct act_return {
+struct op_return {
enum value_type type;
union {
int64_t value;
@@ -89,19 +89,19 @@ struct fd_type {
};
};
-struct act_inject {
+struct op_inject {
struct fd_type newfd;
struct fd_type oldfd;
};
-struct action {
- enum action_type type;
+struct op {
+ enum op_type type;
union {
- struct act_call call;
- struct act_block block;
- struct act_continue cont;
- struct act_return ret;
- struct act_inject inj;
+ struct op_call call;
+ struct op_block block;
+ struct op_continue cont;
+ struct op_return ret;
+ struct op_inject inj;
};
};
#endif /* GLUTEN_H */
@@ -36,20 +36,20 @@ enum ns_type {
};
/*
- * struct act_context - Description of the context where the call needs to be executed
+ * struct op_context - Description of the context where the call needs to be executed
* @ns: Descrption of the each namespace where the call needs to be executed
*/